@@ -1,6 +1,5 @@
 if (requireNamespace("testthat", quietly = TRUE)) {
-  library(testthat)
-  library(checkmate)
-
+  library("testthat")
+  library("checkmate")
   test_check("bbotk")
 }
